# server

HTTP server.

## Features

- Low latency
- Radix tree routing

## Installation

```shell
go get git.akyoto.dev/go/server
```

## Usage

```go
s := server.New()

// Static route
s.Get("/", func(ctx server.Context) error {
	return ctx.String("Hello")
})

// Parameter route
s.Get("/blog/:post", func(ctx server.Context) error {
	return ctx.String(ctx.Get("post"))
})

// Wildcard route
s.Get("/images/*file", func(ctx server.Context) error {
	return ctx.String(ctx.Get("file"))
})

s.Run(":8080")
```

## Tests

```
PASS: TestRouter
PASS: TestMiddleware
PASS: TestPanic
PASS: TestRun
PASS: TestUnavailablePort
coverage: 100.0% of statements
```

## Benchmarks

```
BenchmarkStatic/#00-12          36761953                31.12 ns/op            0 B/op          0 allocs/op
BenchmarkStatic/hello-12        28145253                41.21 ns/op            0 B/op          0 allocs/op
BenchmarkStatic/hello/world-12  21206058                55.10 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub/gists/:id-12    21452644                52.65 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub/repos/:a/:b-12  17888092                61.59 ns/op            0 B/op          0 allocs/op
```

## License

Please see the [license documentation](https://akyoto.dev/license).

## Copyright

© 2023 Eduard Urbach
